==> zio-aws-dynamodb_3-5.17.295.11-sources.jar: zio/aws/dynamodb/model/AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.scala <==
package zio.aws.dynamodb.model
import zio.prelude.data.Optional
import zio.aws.dynamodb.model.primitives.{IntegerObject, BooleanObject}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class AutoScalingTargetTrackingScalingPolicyConfigurationUpdate(
    disableScaleIn: Optional[BooleanObject] = Optional.Absent,
    scaleInCooldown: Optional[IntegerObject] = Optional.Absent,
    scaleOutCooldown: Optional[IntegerObject] = Optional.Absent,
    targetValue: Double
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate = {
    import AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
      .builder()
      .optionallyWith(disableScaleIn.map(value => value: java.lang.Boolean))(
        _.disableScaleIn
      )
      .optionallyWith(scaleInCooldown.map(value => value: Integer))(
        _.scaleInCooldown
      )
      .optionallyWith(scaleOutCooldown.map(value => value: Integer))(
        _.scaleOutCooldown
      )
      .targetValue(targetValue: java.lang.Double)
      .build()
  }
  def asReadOnly
      : zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.ReadOnly =
    zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
      .wrap(buildAwsValue())
}
object AutoScalingTargetTrackingScalingPolicyConfigurationUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate =
      zio.aws.dynamodb.model
        .AutoScalingTargetTrackingScalingPolicyConfigurationUpdate(
          disableScaleIn.map(value => value),
          scaleInCooldown.map(value => value),
          scaleOutCooldown.map(value => value),
          targetValue
        )
    def disableScaleIn: Optional[BooleanObject]
    def scaleInCooldown: Optional[IntegerObject]
    def scaleOutCooldown: Optional[IntegerObject]
    def targetValue: Double
    def getDisableScaleIn: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField("disableScaleIn", disableScaleIn)
    def getScaleInCooldown: ZIO[Any, AwsError, IntegerObject] =
      AwsError.unwrapOptionField("scaleInCooldown", scaleInCooldown)
    def getScaleOutCooldown: ZIO[Any, AwsError, IntegerObject] =
      AwsError.unwrapOptionField("scaleOutCooldown", scaleOutCooldown)
    def getTargetValue: ZIO[Any, Nothing, Double] = ZIO.succeed(targetValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
  ) extends zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.ReadOnly {
    override val disableScaleIn: Optional[BooleanObject] = zio.aws.core.internal
      .optionalFromNullable(impl.disableScaleIn())
      .map(value => value: BooleanObject)
    override val scaleInCooldown: Optional[IntegerObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scaleInCooldown())
        .map(value => value: IntegerObject)
    override val scaleOutCooldown: Optional[IntegerObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scaleOutCooldown())
        .map(value => value: IntegerObject)
    override val targetValue: Double = impl.targetValue(): Double
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
  ): zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-dynamodb_3-6.20.103.1-sources.jar: zio/aws/dynamodb/model/AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.scala <==
package zio.aws.dynamodb.model
import zio.prelude.data.Optional
import zio.aws.dynamodb.model.primitives.{
  DoubleObject,
  IntegerObject,
  BooleanObject
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class AutoScalingTargetTrackingScalingPolicyConfigurationUpdate(
    disableScaleIn: Optional[BooleanObject] = Optional.Absent,
    scaleInCooldown: Optional[IntegerObject] = Optional.Absent,
    scaleOutCooldown: Optional[IntegerObject] = Optional.Absent,
    targetValue: DoubleObject
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate = {
    import AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
      .builder()
      .optionallyWith(disableScaleIn.map(value => value: java.lang.Boolean))(
        _.disableScaleIn
      )
      .optionallyWith(scaleInCooldown.map(value => value: Integer))(
        _.scaleInCooldown
      )
      .optionallyWith(scaleOutCooldown.map(value => value: Integer))(
        _.scaleOutCooldown
      )
      .targetValue(targetValue: java.lang.Double)
      .build()
  }
  def asReadOnly
      : zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.ReadOnly =
    zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
      .wrap(buildAwsValue())
}
object AutoScalingTargetTrackingScalingPolicyConfigurationUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate =
      zio.aws.dynamodb.model
        .AutoScalingTargetTrackingScalingPolicyConfigurationUpdate(
          disableScaleIn.map(value => value),
          scaleInCooldown.map(value => value),
          scaleOutCooldown.map(value => value),
          targetValue
        )
    def disableScaleIn: Optional[BooleanObject]
    def scaleInCooldown: Optional[IntegerObject]
    def scaleOutCooldown: Optional[IntegerObject]
    def targetValue: DoubleObject
    def getDisableScaleIn: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField("disableScaleIn", disableScaleIn)
    def getScaleInCooldown: ZIO[Any, AwsError, IntegerObject] =
      AwsError.unwrapOptionField("scaleInCooldown", scaleInCooldown)
    def getScaleOutCooldown: ZIO[Any, AwsError, IntegerObject] =
      AwsError.unwrapOptionField("scaleOutCooldown", scaleOutCooldown)
    def getTargetValue: ZIO[Any, Nothing, DoubleObject] =
      ZIO.succeed(targetValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
  ) extends zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.ReadOnly {
    override val disableScaleIn: Optional[BooleanObject] = zio.aws.core.internal
      .optionalFromNullable(impl.disableScaleIn())
      .map(value => value: BooleanObject)
    override val scaleInCooldown: Optional[IntegerObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scaleInCooldown())
        .map(value => value: IntegerObject)
    override val scaleOutCooldown: Optional[IntegerObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scaleOutCooldown())
        .map(value => value: IntegerObject)
    override val targetValue: DoubleObject = impl.targetValue(): DoubleObject
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate
  ): zio.aws.dynamodb.model.AutoScalingTargetTrackingScalingPolicyConfigurationUpdate.ReadOnly =
    new Wrapper(impl)
}
